==> optim_esm_tools-3.0.0.tar.gz: optim_esm_tools-3.0.0/README.md <==
# OptimESM Tools
[![Coverage Status](https://coveralls.io/repos/github/JoranAngevaare/optim_esm_tools/badge.svg)](https://coveralls.io/github/JoranAngevaare/optim_esm_tools)
[![PyPI version shields.io](https://img.shields.io/pypi/v/optim-esm-tools.svg)](https://pypi.python.org/pypi/optim-esm-tools/)
[![Python Versions](https://img.shields.io/pypi/pyversions/optim-esm-tools.svg)](https://pypi.python.org/pypi/optim-esm-tools)
[![PyPI downloads](https://img.shields.io/pypi/dm/optim-esm-tools.svg)](https://pypistats.org/packages/optim-esm-tools)
[![CodeFactor](https://www.codefactor.io/repository/github/joranangevaare/optim_esm_tools/badge)](https://www.codefactor.io/repository/github/joranangevaare/optim_esm_tools)


J.R. Angevaare (KNMI)

## Software
This software is used in the scope of the [OptimESM](https://cordis.europa.eu/project/id/101081193) project.
The scientific aim is to isolate regions of three dimensional earth science data from CMIP6 and identify regions of dramatic changes as function of time.

## Setup
This software requires `cdo` and `cartopy`, and preferably also `latex` and `synda`. As the last of this list is only supported in python 3.8 a separate repository [`optim_esm_base`](https://github.com/JoranAngevaare/optim_esm_base]) has a set of software versions that are compatible with these requirements.

After these base requirements are fulfilled, one can install this software via pip
```
pip install optim_esm_tools
```

## Example
The developers are working on an example to be included in a separate folder _coming soon_!

==> optim_esm_tools-3.1.0.tar.gz: optim_esm_tools-3.1.0/README.md <==
# OptimESM Tools
[![Coverage Status](https://coveralls.io/repos/github/JoranAngevaare/optim_esm_tools/badge.svg)](https://coveralls.io/github/JoranAngevaare/optim_esm_tools)
[![PyPI version shields.io](https://img.shields.io/pypi/v/optim-esm-tools.svg)](https://pypi.python.org/pypi/optim-esm-tools/)
[![Python Versions](https://img.shields.io/pypi/pyversions/optim-esm-tools.svg)](https://pypi.python.org/pypi/optim-esm-tools)
[![PyPI downloads](https://img.shields.io/pypi/dm/optim-esm-tools.svg)](https://pypistats.org/packages/optim-esm-tools)
[![CodeFactor](https://www.codefactor.io/repository/github/joranangevaare/optim_esm_tools/badge)](https://www.codefactor.io/repository/github/joranangevaare/optim_esm_tools)


J.R. Angevaare (KNMI)

## Software
This software is used in the scope of the [OptimESM](https://cordis.europa.eu/project/id/101081193) project.
The scientific aim is to isolate regions of three dimensional earth science data from CMIP6 and identify regions of dramatic changes as function of time.

## Setup
This software requires `cdo` and `cartopy`, and preferably also `latex` and `synda`. As the last of this list is only supported in python 3.8 a separate repository [`optim_esm_base`](https://github.com/JoranAngevaare/optim_esm_base) has a set of software versions that are compatible with these requirements.

After these base requirements are fulfilled, one can install this software via pip
```
pip install optim_esm_tools
```

## Example
The developers are working on an example to be included in a separate folder _coming soon_!
